@@ -22,12 +22,17 @@ my %__methods = (
     update_org => { url => "/orgs/%s", method => 'PATCH', args => 1 },
     # Members
     members   => { url => "/orgs/%s/members" },
+    owner_members => { url => "/orgs/%s/members?role=admin" },
+    no_2fa_members => { url => "/orgs/%s/members?filter=2fa_disabled" },
     is_member => { url => "/orgs/%s/members/%s", check_status => 204 },
     delete_member => { url => "/orgs/%s/members/%s", method => 'DELETE', check_status => 204 },
     public_members => { url => "/orgs/%s/public_members" },
     is_public_member => { url => "/orgs/%s/public_members/%s", check_status => 204 },
     publicize_member => { url => "/orgs/%s/public_members/%s", method => 'PUT', check_status => 204 },
     conceal_member => { url => "/orgs/%s/public_members/%s", method => 'DELETE', check_status => 204 },
+    membership => { url => "/orgs/:org/memberships/:username", method => 'GET' },
+    update_membership => { url => "/orgs/:org/memberships/:username", method => 'PUT', args => 1 },
+    delete_membership => { url => "/orgs/:org/memberships/:username", method => 'DELETE', check_status => 204 },
     # Org Teams API
     teams => { url => "/orgs/%s/teams" },
     team  => { url => "/teams/%s" },
@@ -115,6 +120,26 @@ L<http://developer.github.com/v3/orgs/members/>
     my $st = $org->publicize_member('perlchina', 'fayland');
     my $st = $org->conceal_member('perlchina', 'fayland');
 
+=item owner_members
+
+    my @admins = $org->owner_members('perlchina');
+
+=item no_2fa_members
+
+    my @no_2fa_members = $org->no_2fa_members('perlchina');
+
+=item membership
+
+=item update_membership
+
+=item delete_membership
+
+    my $membership = $org->membership('perlchina', 'fayland');
+    my $membership = $org->update_membership('perlchina', 'fayland', {
+        role => 'admin',
+    });
+    my $st = $org->delete_membership('perlchina', 'fayland');
+
 =back
 
 =head3 Org Teams API
